/*******************************************************************************
* File Name: EDW_VDAC8_2_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "EDW_VDAC8_2.h"

static EDW_VDAC8_2_backupStruct EDW_VDAC8_2_backup;


/*******************************************************************************
* Function Name: EDW_VDAC8_2_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void EDW_VDAC8_2_SaveConfig(void) 
{
    if (!((EDW_VDAC8_2_CR1 & EDW_VDAC8_2_SRC_MASK) == EDW_VDAC8_2_SRC_UDB))
    {
        EDW_VDAC8_2_backup.data_value = EDW_VDAC8_2_Data;
    }
}


/*******************************************************************************
* Function Name: EDW_VDAC8_2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void EDW_VDAC8_2_RestoreConfig(void) 
{
    if (!((EDW_VDAC8_2_CR1 & EDW_VDAC8_2_SRC_MASK) == EDW_VDAC8_2_SRC_UDB))
    {
        if((EDW_VDAC8_2_Strobe & EDW_VDAC8_2_STRB_MASK) == EDW_VDAC8_2_STRB_EN)
        {
            EDW_VDAC8_2_Strobe &= (uint8)(~EDW_VDAC8_2_STRB_MASK);
            EDW_VDAC8_2_Data = EDW_VDAC8_2_backup.data_value;
            EDW_VDAC8_2_Strobe |= EDW_VDAC8_2_STRB_EN;
        }
        else
        {
            EDW_VDAC8_2_Data = EDW_VDAC8_2_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: EDW_VDAC8_2_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  EDW_VDAC8_2_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void EDW_VDAC8_2_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(EDW_VDAC8_2_ACT_PWR_EN == (EDW_VDAC8_2_PWRMGR & EDW_VDAC8_2_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        EDW_VDAC8_2_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        EDW_VDAC8_2_backup.enableState = 0u;
    }
    
    EDW_VDAC8_2_Stop();
    EDW_VDAC8_2_SaveConfig();
}


/*******************************************************************************
* Function Name: EDW_VDAC8_2_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  EDW_VDAC8_2_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void EDW_VDAC8_2_Wakeup(void) 
{
    EDW_VDAC8_2_RestoreConfig();
    
    if(EDW_VDAC8_2_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        EDW_VDAC8_2_Enable();

        /* Restore the data register */
        EDW_VDAC8_2_SetValue(EDW_VDAC8_2_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
