/*******************************************************************************
* File Name: Timer_VDAC8_1_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Timer_VDAC8_1.h"

static Timer_VDAC8_1_backupStruct Timer_VDAC8_1_backup;


/*******************************************************************************
* Function Name: Timer_VDAC8_1_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Timer_VDAC8_1_SaveConfig(void) 
{
    if (!((Timer_VDAC8_1_CR1 & Timer_VDAC8_1_SRC_MASK) == Timer_VDAC8_1_SRC_UDB))
    {
        Timer_VDAC8_1_backup.data_value = Timer_VDAC8_1_Data;
    }
}


/*******************************************************************************
* Function Name: Timer_VDAC8_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void Timer_VDAC8_1_RestoreConfig(void) 
{
    if (!((Timer_VDAC8_1_CR1 & Timer_VDAC8_1_SRC_MASK) == Timer_VDAC8_1_SRC_UDB))
    {
        if((Timer_VDAC8_1_Strobe & Timer_VDAC8_1_STRB_MASK) == Timer_VDAC8_1_STRB_EN)
        {
            Timer_VDAC8_1_Strobe &= (uint8)(~Timer_VDAC8_1_STRB_MASK);
            Timer_VDAC8_1_Data = Timer_VDAC8_1_backup.data_value;
            Timer_VDAC8_1_Strobe |= Timer_VDAC8_1_STRB_EN;
        }
        else
        {
            Timer_VDAC8_1_Data = Timer_VDAC8_1_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Timer_VDAC8_1_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Timer_VDAC8_1_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void Timer_VDAC8_1_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(Timer_VDAC8_1_ACT_PWR_EN == (Timer_VDAC8_1_PWRMGR & Timer_VDAC8_1_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Timer_VDAC8_1_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Timer_VDAC8_1_backup.enableState = 0u;
    }
    
    Timer_VDAC8_1_Stop();
    Timer_VDAC8_1_SaveConfig();
}


/*******************************************************************************
* Function Name: Timer_VDAC8_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Timer_VDAC8_1_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Timer_VDAC8_1_Wakeup(void) 
{
    Timer_VDAC8_1_RestoreConfig();
    
    if(Timer_VDAC8_1_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Timer_VDAC8_1_Enable();

        /* Restore the data register */
        Timer_VDAC8_1_SetValue(Timer_VDAC8_1_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
